@@ -2,7 +2,7 @@ import ast
 import logging
 import tempfile
 
-from fabric.api import local, settings
+from plumbum.cmd import diff
 from path import path
 
 
@@ -18,6 +18,7 @@ def extract_attribute(module_name, attribute_name):
 
 
 def replace_attribute(module_name, attribute_name, new_value, dry_run=True):
+    """Update a metadata attribute"""
     init_file = '%s/__init__.py' % module_name
     _, tmp_file = tempfile.mkstemp()
 
@@ -32,11 +33,11 @@ def replace_attribute(module_name, attribute_name, new_value, dry_run=True):
     if not dry_run:
         path(tmp_file).move(init_file)
     else:
-        with settings(warn_only=True):
-            log.info(local('diff %s %s' % (tmp_file, init_file)))
+        log.info(diff(tmp_file, init_file, retcode=None))
 
 
 def has_attribute(module_name, attribute_name):
+    """Is this attribute present?"""
     init_file = '%s/__init__.py' % module_name
     return any(
         [attribute_name in init_line for
